#! /usr/bin/env python
# -*- coding: utf-8 -*_
# Copyright (C) 2018 Liu Yang <mkliuyang@gmail.com> All rights reserved.

from distutils.core import setup

setup(name='enoch',
      version='0.0.1',
      description='Python Base Utilities',
      author='Liu Yang',
      author_email='mkliuyang@gmail.com',
      url='https://www.python.org/liu946/enoch/',
     )
